:hide-toc:

.. container::
   :name: forkongithub

   `Fork on GitHub <https://github.com/agilescientific/redflag>`_


Redflag: An Entrance Exam for Data
==================================

    | 🚩 ``redflag`` aims to be an automatic safety net for
    | machine learning datasets. Given a ``DataFrame`` or
    | ``ndarray``, ``redflag`` will analyse each feature,
    | including aspects such as class imbalance, outliers,
    | anomalous data patterns, threats to the IID assumption,
    | and so on.

.. attention::
    This project is quite rough and does not do much yet.
    The API will very likely change without warning.
    If you think it might be useful, please consider
    helping to improve the project!


Quick start
-----------

.. toctree::
    :caption: Quick start

Install ``redflag`` with pip:

.. code-block:: shell

    pip install redflag

Carry on exploring with the user guide below.


User guide
----------

.. toctree::
    :maxdepth: 2
    :caption: User guide

    installation
    _notebooks/Basic_usage.ipynb
    _notebooks/Using_redflag_with_sklearn.ipynb


API reference
-------------

.. toctree::
    :maxdepth: 2
    :caption: API reference

    redflag


Other resources
---------------

.. toctree::
    :maxdepth: 1
    :caption: Other resources

    development
    contributing
    authors
    license
    changelog


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. toctree::
    :caption: Project links
    :hidden:

    PyPI releases <https://pypi.org/project/redflag/>
    Code in GitHub <https://github.com/agilescientific/redflag>
    Issue tracker <https://github.com/agilescientific/redflag/issues>
    Community guidelines <https://code.agilescientific.com/community>
    Agile's software <https://code.agilescientific.com>
    Agile's website <https://www.agilescientific.com>
